@@ -58,29 +58,31 @@ class Freebox(IPlugin):
 				log.msg(" boy  :  %s" % (rs['boy']))
 				bodies = rs['boy']
 				log.msg("BODIES  :  %s" % (bodies))
-				if rs['idx_sec'] <> "1":
+				if rs['idx_sec'] = "2":
 					log.msg("*************  'idx_sec'] <> 1 ****************")
 					# séparation de rs['idx'], nombre   len(maliste)
-					i = 1
-				#	while i = rs['idx_sec']:
-					for i in rs['idx_sec']:
-							if rs['idx'][i - rang] == '|':
-								rangs.append(rang)
-								log.msg(" rang  :  %s" % (rangs))
+					lg=len(rs['idx'])		
+					log.msg(" lg  :  %s" % (lg))
+					for bar in range lg
+##				#	while i = rs['idx_sec']:
+##						for i in rs['idx_sec']:
+##								if rs['idx'][i - rang] == '|':
+##									rangs.append(rang)
+##									log.msg(" rang  :  %s" % (rangs))
 #>>> for rang in range(len(mot)):  # La variable rang parcourt les entiers de 0 au rang de la dernière lettre du mot.
 #...     if mot[rang] == 'i':
 #...         rangs.append(rang)    # Si la lettre du mot est 'i', on stocke le rang dans notre liste.
 #>>> rangs                         # On affiche le résultat.
 #[5, 7]
-						# search position '|' dans rs['idx']	
-						# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
+##							# search position '|' dans rs['idx']	
+##							# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
 							for rx in rs['idx_sec']:
 								log.msg(" rx  :  %s" % (rx))
 								log.msg("idx_sec  :  %s" % rs['idx_sec'])
 								log.msg("idx  :  %s" % (rs['idx']))
 								resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
 							log.msg("resp  :  %s" % (resp))
-				else:
+				if rs['idx_sec'] = "1":
 					log.msg("*************  'idx_sec'] = 1 ****************")
 					resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
 					log.msg("resp unique   :  %s" % (resp))
